import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';

import 'package:random/ui/screens/skeleton_screen.dart';
import 'package:random/config/theme.dart';
import 'package:random/activities/ActivityDemoPage.dart';
import 'package:random/activities/ActivityGraphPage.dart';

void main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await EasyLocalization.ensureInitialized();

  runApp(
    EasyLocalization(
      path: 'assets/translations',
      supportedLocales: const <Locale>[
        Locale('en'),
        Locale('fr'),
      ],
      fallbackLocale: const Locale('en'),
      useFallbackTranslations: true,
      child: const MyApp(),
    ),
  );
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Random application',
      theme: appTheme,
      home: SkeletonScreen(),
      onGenerateRoute: (settings) {
        switch (settings.name) {
          case ActivityDemoPage.route:
            {
              return MaterialPageRoute(
                builder: (context) => ActivityDemoPage(),
              );
            }
          case ActivityGraphPage.route:
            {
              return MaterialPageRoute(
                builder: (context) => ActivityGraphPage(),
              );
            }

          default:
            {
              print("Unknown menu entry: " + settings.name.toString());
            }
            break;
        }

        return null;
      },

      // Localization stuff
      localizationsDelegates: context.localizationDelegates,
      supportedLocales: context.supportedLocales,
      locale: context.locale,
      debugShowCheckedModeBanner: false,
    );
  }
}
